@@ -1,5 +1,6 @@
 function closeWindow(aClose, aPromptFunction)
 {
+//@line 5 "/builds/slave/firefox-lorentz-linux-xulrunner/build/toolkit/content/globalOverlay.js"
   var windowCount = 0;
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
@@ -11,12 +12,20 @@ function closeWindow(aClose, aPromptFunction)
       break;
   }
 
-//@line 16 "/builds/slave/191-lnx-xr/build/toolkit/content/globalOverlay.js"
+  var inPrivateBrowsing = false;
+  try {
+    var pbSvc = Components.classes["@mozilla.org/privatebrowsing;1"]
+                          .getService(Components.interfaces.nsIPrivateBrowsingService);
+    inPrivateBrowsing = pbSvc.privateBrowsingEnabled;
+  } catch(e) {
+    // safe to ignore
+  }
+
   // If we're down to the last window and someone tries to shut down, check to make sure we can!
   if (windowCount == 1 && !canQuitApplication())
     return false;
-  else if (windowCount != 1)
-//@line 21 "/builds/slave/191-lnx-xr/build/toolkit/content/globalOverlay.js"
+  else if (windowCount != 1 || inPrivateBrowsing)
+//@line 30 "/builds/slave/firefox-lorentz-linux-xulrunner/build/toolkit/content/globalOverlay.js"
     if (typeof(aPromptFunction) == "function" && !aPromptFunction())
       return false;
 
@@ -73,7 +82,8 @@ function goUpdateCommand(aCommand)
     goSetCommandEnabled(aCommand, enabled);
   }
   catch (e) {
-    dump("An error occurred updating the " + aCommand + " command\n");
+    Components.utils.reportError("An error occurred updating the " +
+                                 aCommand + " command: " + e);
   }
 }
 
@@ -86,7 +96,8 @@ function goDoCommand(aCommand)
       controller.doCommand(aCommand);
   }
   catch (e) {
-    dump("An error occurred executing the " + aCommand + " command\n" + e + "\n");
+    Components.utils.reportError("An error occurred executing the " +
+                                 aCommand + " command: " + e);
   }
 }
 
@@ -166,11 +177,6 @@ function visitLink(aEvent) {
     protocolSvc.loadUrl(uri);
 }
 
-function isValidLeftClick(aEvent, aName)
-{
-  return (aEvent.button == 0 && aEvent.originalTarget.localName == aName);
-}
-
 function setTooltipText(aID, aTooltipText)
 {
   var element = document.getElementById(aID);
@@ -178,23 +184,6 @@ function setTooltipText(aID, aTooltipText)
     element.setAttribute("tooltiptext", aTooltipText);
 }
 
-function FillInTooltip ( tipElement )
-{
-  var retVal = false;
-  var textNode = document.getElementById("TOOLTIP-tooltipText");
-  if (textNode) {
-    while (textNode.hasChildNodes())
-      textNode.removeChild(textNode.firstChild);
-    var tipText = tipElement.getAttribute("tooltiptext");
-    if (tipText) {
-      var node = document.createTextNode(tipText);
-      textNode.appendChild(node);
-      retVal = true;
-    }
-  }
-  return retVal;
-}
-
 __defineGetter__("NS_ASSERT", function() {
   delete this.NS_ASSERT;
   var tmpScope = {};
